@@ -4,8 +4,7 @@
 Author: Jeroen van der Heijden (Transceptor Technology)
 Date: 2016-10-10
 '''
-# import sys
-# sys.path.insert(0, '../../pyleri/')
+import sys
 import os
 from grammar import siri_grammar
 from pyleri import Grammar
