@@ -1,15 +1,9 @@
 /*
- * iso8601.h - Library to parse ISO 8601 dates
- *
- * author       : Jeroen van der Heijden
- * email        : jeroen@transceptor.technology
- * copyright    : 2016, Transceptor Technology
- *
- * changes
- *  - initial version, 21-04-2016
- *
+ * iso8601.h - Library to parse ISO 8601 dates. Time-zones are found with
+ *             tzset() in either /usr/lib/zoneinfo/ or /usr/share/zoneinfo/.
  */
-#pragma once
+#ifndef ISO8601_H_
+#define ISO8601_H_
 
 #include <inttypes.h>
 
@@ -31,3 +25,5 @@ const char * iso8601_tzname(iso8601_tz_t tz);
  * in the string.
  */
 int64_t iso8601_parse_date(const char * str, iso8601_tz_t tz);
+
+#endif  /* ISO8601_H_ */
