@@ -18,20 +18,26 @@ void siri_cfg_destroy(siri_t * siri);
 
 struct siri_cfg_s
 {
+    uint32_t optimize_interval;
+    uint32_t buffer_sync_interval;
+
     uint16_t listen_client_port;
     uint16_t listen_backend_port;
-    char * bind_client_addr;
-    char * bind_backend_addr;
     uint16_t heartbeat_interval;
     uint16_t max_open_files;
-    uint32_t optimize_interval;
+
+    uint16_t http_status_port;
+    uint16_t pad0_;
+    uint8_t pipe_support;
     uint8_t ip_support;
     uint8_t shard_compression;
+    uint8_t pad1_;
+
+    char * bind_client_addr;
+    char * bind_backend_addr;
     char server_address[SIRI_CFG_MAX_LEN_ADDRESS];
     char default_db_path[XPATH_MAX];
-    uint8_t pipe_support;
     char pipe_client_name[XPATH_MAX];
-    uint32_t buffer_sync_interval;
 };
 
 #endif  /* SIRI_CFG_H_ */
