@@ -20,7 +20,7 @@ bool xstr_is_empty(const char * str);
 bool xstr_is_int(const char * str);
 bool xstr_is_float(const char * str);
 bool xstr_is_graph(const char * str);
-double xstr_to_double(const char * src, size_t len);
+double xstr_to_double(const char * src);
 uint64_t xstr_to_uint64(const char * src, size_t len);
 char * xstr_dup(const char * src, size_t * n);
 
