@@ -217,6 +217,13 @@ class TestSelect(TestBase):
                 [1447254000, 31530.520833333332],
                 [1447257600, 4.666666666666667]]})
 
+        self.assertEqual(
+            await self.client0.query('select * from ({}) - ("a", "b")'.format(
+                ','.join(['"aggr"'] * 600)
+            )),
+            {'aggr': DATA['aggr']}
+        )
+
         self.assertEqual(
             await self.client0.query('select difference(1h) from "aggr"'),
             {'aggr': [[1447250400, 1], [1447254000, -3], [1447257600, 5]]})
@@ -428,7 +435,9 @@ class TestSelect(TestBase):
                 QueryError,
                 'Memory allocation error or maximum recursion depth reached.'):
             await self.client0.query(
-                'select * from "aggr" where length > {}'.format('(' * 500))
+                'select * from {}"aggr"{}'.format(
+                    '(' * 501,
+                    ')' * 501))
 
         with self.assertRaisesRegex(
                     QueryError,
