@@ -22,6 +22,7 @@
 #define DEFAULT_OPEN_FILES_LIMIT MAX_OPEN_FILES_LIMIT
 
 static siri_cfg_t siri_cfg = {
+        .http_status_port=0,    /* 0=disabled, 1-16535=enabled */
         .listen_client_port=9000,
         .listen_backend_port=9010,
         .bind_client_addr=NULL,
@@ -112,6 +113,15 @@ void siri_cfg_init(siri_t * siri)
             &tmp);
     siri_cfg.heartbeat_interval = (uint16_t) tmp;
 
+    tmp = siri_cfg.http_status_port;
+    SIRI_CFG_read_uint(
+            cfgparser,
+            "http_status_port",
+            0,
+            65535,
+            &tmp);
+    siri_cfg.http_status_port = (uint16_t) tmp;
+
     SIRI_CFG_read_default_db_path(cfgparser);
     SIRI_CFG_read_max_open_files(cfgparser);
     SIRI_CFG_read_ip_support(cfgparser);
