@@ -179,7 +179,9 @@ int siridb_buffer_new_series(
     series->buffer = siridb_points_new(buffer->len, series->tp);
     if (series->buffer == NULL)
     {
-        return -1;  /* signal is raised */
+        /* TODO: maybe we can remove the ERR_ALLOC */
+        ERR_ALLOC
+        return -1;
     }
 
     return (buffer->empty->len) ?
@@ -192,7 +194,6 @@ int siridb_buffer_new_series(
  */
 int siridb_buffer_open(siridb_buffer_t * buffer)
 {
-    const int flags = POSIX_FADV_RANDOM | POSIX_FADV_DONTNEED;
     int rc;
     siridb_misc_get_fn(fn, buffer->path, SIRIDB_BUFFER_FN)
 
@@ -215,6 +216,7 @@ int siridb_buffer_open(siridb_buffer_t * buffer)
 #ifdef __APPLE__
     rc = 0;  /* no posix_fadvise on apple */
 #else
+    const int flags = POSIX_FADV_RANDOM | POSIX_FADV_DONTNEED;
     rc = posix_fadvise(buffer->fd, 0, 0, flags);
     if (rc)
     {
