@@ -199,6 +199,12 @@ void siridb_query_send_error(
         cproto_server_t err)
 {
     siridb_query_t * query = (siridb_query_t *) handle->data;
+
+    /* make sure the error message is null terminated in case the length has
+     * exceeded the max length.
+     */
+    query->err_msg[SIRIDB_MAX_SIZE_ERR_MSG-1] = '\0';
+
     sirinet_pkg_t * package = sirinet_pkg_err(
                 query->pid,
                 strlen(query->err_msg),
@@ -399,6 +405,26 @@ void siridb_query_timeit_from_unpacker(
     }
 }
 
+static void QUERY_unique(cleri_olist_t * olist)
+{
+    while (olist != NULL && olist->next != NULL)
+    {
+        cleri_olist_t * test = olist;
+        while (test->next != NULL)
+        {
+            if (olist->cl_obj == test->next->cl_obj)
+            {
+                cleri_olist_t * tmp = test->next->next;
+                free(test->next);
+                test->next = tmp;
+                continue;
+            }
+            test = test->next;
+        }
+        olist = olist->next;
+    }
+}
+
 static void QUERY_send_invalid_error(uv_async_t * handle)
 {
     size_t len;
@@ -413,6 +439,9 @@ static void QUERY_send_invalid_error(uv_async_t * handle)
             "Query error at position %zd. Expecting ",
             query->pr->pos);
 
+    /* required for libcleri versions prior to 0.10.1 */
+    QUERY_unique(query->pr->expecting->required);
+
     /* expand the error message with suggestions. we try to add nice names
      * for regular expressions etc.
      */
@@ -985,7 +1014,7 @@ static int QUERY_rebuild(
             return 0;
         }
     /* FALLTHRU */
-    /* no break */
+    /* fall through */
     default:
         {
             int rc;
