@@ -873,7 +873,7 @@ int siridb_server_drop(siridb_t * siridb, siridb_server_t * server)
         pool->server[0] = pool->server[1];
         pool->server[0]->id = 0;
         /* FALLTHRU */
-        /* no break */
+        /* fall through */
     case 1:
         pool->server[1] = NULL;
         pool->len = 1;
@@ -933,7 +933,6 @@ void siridb__server_free(siridb_server_t * server)
      */
     if (server->promises != NULL)
     {
-        imap_walk(server->promises, (imap_cb) SERVER_cancel_promise, NULL);
         imap_free(server->promises, (imap_free_cb) SERVER_cancel_promise);
     }
     free(server->name);
