@@ -23,7 +23,7 @@
 #define SIRIDB_SERVERS_FN "servers.dat"
 #define SIRIDB_SERVERS_SCHEMA 1
 
-static void SERVERS_walk_free(siridb_server_t * server, void * args);
+static int SERVERS_walk_free(siridb_server_t * server, void * args);
 static int SERVERS_walk_save(siridb_server_t * server, qp_fpacker_t * fpacker);
 
 /*
@@ -372,6 +372,7 @@ void siridb_servers_send_pkg(
     }
     else
     {
+        sirinet_pkg_t * dup;
         siridb_server_t * server;
         size_t i;
 
@@ -381,13 +382,14 @@ void siridb_servers_send_pkg(
 
             if (siridb_server_is_online(server))
             {
-                if (siridb_server_send_pkg(
+                if ((dup = sirinet_pkg_dup(pkg)) == NULL ||
+                    siridb_server_send_pkg(
                         server,
-                        pkg,
+                        dup,
                         timeout,
                         (sirinet_promise_cb) sirinet_promises_on_response,
                         promises,
-                        FLAG_KEEP_PKG))
+                        0 /* flags */))
                 {
                     log_critical(
                             "Allocation error while trying to send a package "
@@ -786,11 +788,12 @@ int siridb_servers_save(siridb_t * siridb)
     return 0;
 }
 
-static void SERVERS_walk_free(
+static int SERVERS_walk_free(
         siridb_server_t * server,
         void * args __attribute__((unused)))
 {
     siridb_server_decref(server);
+    return 0;
 }
 
 static int SERVERS_walk_save(siridb_server_t * server, qp_fpacker_t * fpacker)
